searchData={"items":[{"type":"module","title":"PhoenixReverseProxy","doc":"This Library provides everything you need to route requests and websockets\nfrom one proxy app into your umbrella. This allows you to have multiple phoenix\napplications in the same umbrella sharing the same port number.\n\nStart by creating a Phoenix application in your umbrella `apps` folder:\n```bash\n(cd apps && mix phx.new --no-webpack --no-ecto --no-html --no-gettext --no-dashboard reverse_proxy)\n# Optionally you can delete unused files\nrm -rf apps/reverse_proxy/lib/reverse_proxy_web/{channels,controllers,views}\n```\n\nIn `apps/reverse_proxy/lib/reverse_proxy_web/endpoint.ex` replace the contents with\nthis and replace the default endpoint and add appropriate endpoints:\n```elixir\ndefmodule ReverseProxyWeb.Endpoint do\n  use PhoenixReverseProxy, otp_app: :reverse_proxy\n\n  # IMPORTANT: All of these macros except for proxy_default/1\n  #            can take a path prefix so they all have an arity\n  #            of 2 and 3.\n\n  # Maps to http(s)://api.example.com/v1\n  # proxy(\"api.example.com\", \"v1\", ExampleApiV1.Endpoint)\n\n  # Maps to http(s)://api.example.com/v2\n  # proxy(\"api.example.com\", \"v2\", ExampleApiV2.Endpoint)\n\n  # Matches the domain only and no subdomains\n  # proxy(\"example.com\", ExampleWeb.Endpoint)\n  # Matched any subdomain such as http(s)://images.example.com/\n  # but not the domain itself http(s)://example.com/\n  # proxy_subdomains(\"example.com\", ExampleSubs.Endpoint)\n\n  # Matches all subdomains and the domain itself.\n  # This is equivalent to combining these rules:\n  #   proxy(\"foofoovalve.com\", FoofooValve.Endpoint)\n  #   proxy_subdomains(\"foofoovalve.com\", FoofooValve.Endpoint)\n  # proxy_all(\"foofoovalve.com\", FoofooValve.Endpoint)\n\n  # Matches anything not matched above\n  proxy_default(ExampleWeb.Endpoint)\nend\n```\n\nIn your config you must disable your other Phoenix applications from\nlistening on TCP ports. In your current endpoint configuration make the\nfollowing modifications.\n\n```elixir\n# Configures the endpoint\nconfig :example_web, ExampleWeb.Endpoint,\n  # Add this\n  server: false,\n  # Remove this and add it to the proxy endpoint configuration\n  http: [port: System.get_env(\"PHX_PORT\") || 4000],\n  ...\n```\n\nMove contents of the files `apps/reverse_proxy/config/*.exs` to the\ncorresponding `config/*.exs` config files.","ref":"PhoenixReverseProxy.html"},{"type":"macro","title":"PhoenixReverseProxy.proxy/2","doc":"Sets the Phoenix endpoint for a specific hostname. Note that more specific\nmatches are matched first regardless of the order in which they are specified.","ref":"PhoenixReverseProxy.html#proxy/2"},{"type":"macro","title":"Examples - PhoenixReverseProxy.proxy/2","doc":"```\nproxy(\"example.com\", ExampleWeb.Endpoint)\nproxy(\"example.com\", \"v1/oauth\", OAuthWebV1.Endpoint) # This matches first\n```","ref":"PhoenixReverseProxy.html#proxy/2-examples"},{"type":"macro","title":"PhoenixReverseProxy.proxy/3","doc":"Sets the Phoenix endpoint for a specific hostname and a prefix of the path.\nNote that more specific matches are matched first regardless of the order in which\nthey are specified.","ref":"PhoenixReverseProxy.html#proxy/3"},{"type":"macro","title":"Examples - PhoenixReverseProxy.proxy/3","doc":"```\nproxy(\"example.com\", ExampleWeb.Endpoint)\n# For http(s)://example.com/oauth\nproxy(\"example.com\", \"v1/oauth\", OAuthWebV1.Endpoint) # This matches first\n```","ref":"PhoenixReverseProxy.html#proxy/3-examples"},{"type":"macro","title":"PhoenixReverseProxy.proxy_all/2","doc":"Sets the Phoenix endpoint for a set of subdomains including the domain itself.\nNote that more specific matches are matched first regardless of the order in\nwhich they are specified.","ref":"PhoenixReverseProxy.html#proxy_all/2"},{"type":"macro","title":"Examples - PhoenixReverseProxy.proxy_all/2","doc":"```\nproxy_all(\"example.com\", OAuthWeb.Endpoint)\n# Which is equivalent to:\nproxy(\"example.com\", OAuthWeb.Endpoint)\nproxy_subdomains(\"example.com\", OAuthWeb.Endpoint)\n```","ref":"PhoenixReverseProxy.html#proxy_all/2-examples"},{"type":"macro","title":"PhoenixReverseProxy.proxy_all/3","doc":"Sets the Phoenix endpoint for a set of subdomains including the domain\nitself as well as a prefix of the path. Note that more specific\nmatches are matched first regardless of the order in which they are\nspecified.","ref":"PhoenixReverseProxy.html#proxy_all/3"},{"type":"macro","title":"Examples - PhoenixReverseProxy.proxy_all/3","doc":"```\nproxy_all(\"example.com\", \"v1/oauth\", OAuthWebV1.Endpoint)\n# Which is equivalent to:\nproxy(\"example.com\", \"v1/oauth\", OAuthWebV1.Endpoint)\nproxy_subdomains(\"example.com\", \"v1/oauth\", OAuthWebV1.Endpoint)\n```","ref":"PhoenixReverseProxy.html#proxy_all/3-examples"},{"type":"macro","title":"PhoenixReverseProxy.proxy_default/1","doc":"Sets the default Phoenix endpoint to send requests to if we cannot match against anything.","ref":"PhoenixReverseProxy.html#proxy_default/1"},{"type":"macro","title":"Examples - PhoenixReverseProxy.proxy_default/1","doc":"```\nproxy_default(ExampleWeb.Endpoint)\n```","ref":"PhoenixReverseProxy.html#proxy_default/1-examples"},{"type":"macro","title":"PhoenixReverseProxy.proxy_path/2","doc":"Sets the Phoenix endpoint for a specific a prefix of a path.\nNote that more specific matches are matched first regardless of the order in which\nthey are specified.","ref":"PhoenixReverseProxy.html#proxy_path/2"},{"type":"macro","title":"Examples - PhoenixReverseProxy.proxy_path/2","doc":"```\nproxy_path(\"v1/auth\", AuthWebV1.Endpoint)","ref":"PhoenixReverseProxy.html#proxy_path/2-examples"},{"type":"macro","title":"PhoenixReverseProxy.proxy_subdomains/2","doc":"Sets the Phoenix endpoint for a set of subdomains excluding the domain itself.\nNote that more specific matches are matched first regardless of the order in\nwhich they are specified.","ref":"PhoenixReverseProxy.html#proxy_subdomains/2"},{"type":"macro","title":"Examples - PhoenixReverseProxy.proxy_subdomains/2","doc":"```\nproxy_subdomains(\"example.com\", ExampleWeb.Endpoint)\n```","ref":"PhoenixReverseProxy.html#proxy_subdomains/2-examples"},{"type":"macro","title":"PhoenixReverseProxy.proxy_subdomains/3","doc":"Sets the Phoenix endpoint for a set of subdomains excluding the domain\nitself as well as a prefix of the path. Note that more specific\nmatches are matched first regardless of the order in which they are\nspecified.","ref":"PhoenixReverseProxy.html#proxy_subdomains/3"},{"type":"macro","title":"Examples - PhoenixReverseProxy.proxy_subdomains/3","doc":"```\nproxy_subdomains(\"example.com\", \"v1/oauth\", OAuthWebV1.Endpoint)\n```","ref":"PhoenixReverseProxy.html#proxy_subdomains/3-examples"},{"type":"function","title":"PhoenixReverseProxy.reverse_domain/1","doc":"Reverse a domain name string (ASCII). This is used internally for pattern\nmatching of subdomains.","ref":"PhoenixReverseProxy.html#reverse_domain/1"},{"type":"function","title":"Examples - PhoenixReverseProxy.reverse_domain/1","doc":"iex> PhoenixReverseProxy.reverse_domain(\"abc.com\")\n    \"moc.cba\"","ref":"PhoenixReverseProxy.html#reverse_domain/1-examples"},{"type":"extras","title":"PhoenixReverseProxy","doc":"# PhoenixReverseProxy\n\n**Share a port between many Phoenix apps in an umbrella or multiple endpoints in a single app**","ref":"readme.html"},{"type":"extras","title":"Setup - PhoenixReverseProxy","doc":"This library offers all the essentials for directing requests and websockets\nfrom a single proxy application to your umbrella (or a standard Elixir app\nwith various endpoints). It enables you to run multiple Phoenix applications\nwithin the same umbrella using the same port or have multiple endpoints\nwithin a single app.\n\nStart by creating a Phoenix application in your umbrella `apps` folder:\n  ```bash\n  (cd apps && mix phx.new --no-webpack --no-ecto --no-html --no-gettext --no-dashboard reverse_proxy)\n  # Optionally you can delete unused files\n  rm -rf apps/reverse_proxy/lib/reverse_proxy_web/{channels,controllers,views}\n  ```\n\nIf [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `phoenix_reverse_proxy` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:phoenix_reverse_proxy, \"~> 1.1.0\"}\n  ]\nend\n```\n\nIn `apps/reverse_proxy/lib/reverse_proxy_web/endpoint.ex` replace the contents with\nthis and replace the default endpoint and add appropriate endpoints:\n  ```elixir\n  defmodule ReverseProxyWeb.Endpoint do\n    use PhoenixReverseProxy, otp_app: :reverse_proxy\n\n    # IMPORTANT: All of these macros except for proxy_default/1\n    #            can take a path prefix so they all have an arity\n    #            of 2 and 3.\n\n    # Maps to http(s)://api.example.com/v1\n    proxy(\"api.example.com\", \"v1\", ExampleApiV1.Endpoint)\n\n    # Maps to http(s)://api.example.com/v2\n    proxy(\"api.example.com\", \"v2\", ExampleApiV2.Endpoint)\n\n    # Matches the domain only and no subdomains\n    proxy(\"example.com\", ExampleWeb.Endpoint)\n    # Matched any subdomain such as http(s)://images.example.com/\n    # but not the domain itself http(s)://example.com/\n    proxy_subdomains(\"example.com\", ExampleSubs.Endpoint)\n\n    # Matches all subdomains and the domain itself.\n    # This is equivalent to combining these rules:\n    #   proxy(\"foofoovalve.com\", FoofooValve.Endpoint)\n    #   proxy_subdomains(\"foofoovalve.com\", FoofooValve.Endpoint)\n    proxy_all(\"foofoovalve.com\", FoofooValve.Endpoint)\n\n    # Matches anything not matched above\n    proxy_default(ExampleWeb.Endpoint)\n  end\n  ```\n\nIn your config you must disable your other Phoenix applications from\nlistening on TCP ports. In your current endpoint configuration make the\nfollowing modifications.\n\n  ```elixir\n  # Configures the endpoint\n  config :example_web, ExampleWeb.Endpoint,\n    # Add this\n    server: false,\n    # Remove this and add it to the proxy endpoint configuration\n    http: [port: System.get_env(\"PHX_PORT\") || 4000],\n    ...\n  ```\n\nMove contents of the files `apps/reverse_proxy/config/*.exs` to the\ncorresponding `config/*.exs` config files.\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at [https://hexdocs.pm/phoenix_reverse_proxy](https://hexdocs.pm/phoenix_reverse_proxy).","ref":"readme.html#setup"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,48]}}